# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkRegionFromReferenceLabelMapFilterPython
else:
    import _itkRegionFromReferenceLabelMapFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkRGBPixelPython
import itk.itkChangeRegionLabelMapFilterPython
import itk.itkStatisticsLabelObjectPython
import itk.itkHistogramPython
import itk.itkSamplePython
import itk.itkArrayPython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkOptimizerParametersPython
import itk.itkArray2DPython
import itk.itkVariableLengthVectorPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkShapeLabelObjectPython
import itk.itkLabelObjectPython
import itk.itkLabelObjectLinePython
import itk.itkInPlaceLabelMapFilterPython
import itk.itkLabelMapFilterPython
import itk.ITKLabelMapBasePython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkRegionFromReferenceLabelMapFilterLM2_New():
    return itkRegionFromReferenceLabelMapFilterLM2.New()

class itkRegionFromReferenceLabelMapFilterLM2(itk.itkChangeRegionLabelMapFilterPython.itkChangeRegionLabelMapFilterLM2):
    r"""Proxy of C++ itkRegionFromReferenceLabelMapFilterLM2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRegionFromReferenceLabelMapFilterLM2_Pointer"""
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRegionFromReferenceLabelMapFilterLM2_Pointer"""
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM2_Clone(self)

    def SetReferenceImage(self, image):
        r"""
        SetReferenceImage(self, image)

        Parameters
        ----------
        image: itkImageBase2 const *

        """
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM2_SetReferenceImage(self, image)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase2"""
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM2_GetReferenceImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkLabelMap2 const *

        """
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageBase2 const *

        """
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM2_SetInput2(self, input)
    __swig_destroy__ = _itkRegionFromReferenceLabelMapFilterPython.delete_itkRegionFromReferenceLabelMapFilterLM2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRegionFromReferenceLabelMapFilterLM2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRegionFromReferenceLabelMapFilterLM2

        Create a new object of the class itkRegionFromReferenceLabelMapFilterLM2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRegionFromReferenceLabelMapFilterLM2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRegionFromReferenceLabelMapFilterLM2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRegionFromReferenceLabelMapFilterLM2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRegionFromReferenceLabelMapFilterLM2 in _itkRegionFromReferenceLabelMapFilterPython:
_itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM2_swigregister(itkRegionFromReferenceLabelMapFilterLM2)

def itkRegionFromReferenceLabelMapFilterLM3_New():
    return itkRegionFromReferenceLabelMapFilterLM3.New()

class itkRegionFromReferenceLabelMapFilterLM3(itk.itkChangeRegionLabelMapFilterPython.itkChangeRegionLabelMapFilterLM3):
    r"""Proxy of C++ itkRegionFromReferenceLabelMapFilterLM3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRegionFromReferenceLabelMapFilterLM3_Pointer"""
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRegionFromReferenceLabelMapFilterLM3_Pointer"""
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM3_Clone(self)

    def SetReferenceImage(self, image):
        r"""
        SetReferenceImage(self, image)

        Parameters
        ----------
        image: itkImageBase3 const *

        """
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM3_SetReferenceImage(self, image)

    def GetReferenceImage(self):
        r"""GetReferenceImage(self) -> itkImageBase3"""
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM3_GetReferenceImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkLabelMap3 const *

        """
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageBase3 const *

        """
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM3_SetInput2(self, input)
    __swig_destroy__ = _itkRegionFromReferenceLabelMapFilterPython.delete_itkRegionFromReferenceLabelMapFilterLM3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRegionFromReferenceLabelMapFilterLM3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRegionFromReferenceLabelMapFilterLM3

        Create a new object of the class itkRegionFromReferenceLabelMapFilterLM3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRegionFromReferenceLabelMapFilterLM3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRegionFromReferenceLabelMapFilterLM3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRegionFromReferenceLabelMapFilterLM3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRegionFromReferenceLabelMapFilterLM3 in _itkRegionFromReferenceLabelMapFilterPython:
_itkRegionFromReferenceLabelMapFilterPython.itkRegionFromReferenceLabelMapFilterLM3_swigregister(itkRegionFromReferenceLabelMapFilterLM3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def region_from_reference_label_map_filter(*args: itkt.ImageLike,  reference_image: itkt.ImageBase=..., region: itkt.ImageRegion=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for RegionFromReferenceLabelMapFilter"""
    import itk

    kwarg_typehints = { 'reference_image':reference_image,'region':region }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.RegionFromReferenceLabelMapFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def region_from_reference_label_map_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLabelMap.RegionFromReferenceLabelMapFilter
    region_from_reference_label_map_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    region_from_reference_label_map_filter.__doc__ = filter_object.__doc__



